@@ -53,7 +53,7 @@ static gboolean output_sexp (MuMsgIter *iter, gboolean threads,
 static gboolean output_xml (MuMsgIter *iter,gboolean include_unreadable,
 			    GError **err);
 static gboolean output_plain (MuMsgIter *iter, const char *fields,
-			      gboolean summary,gboolean threads,
+			      int summary_len, gboolean threads,
 			      gboolean color,  gboolean include_unreadable,
 			      GError **err);
 
@@ -86,7 +86,7 @@ sort_field_from_string (const char* fieldstr, GError **err)
 		mfid = mu_msg_field_id_from_shortcut(fieldstr[0],
 						     FALSE);
 	if (mfid == MU_MSG_FIELD_ID_NONE)
-		g_set_error (err, 0, MU_ERROR_IN_PARAMETERS,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_IN_PARAMETERS,
 			     "not a valid sort field: '%s'\n", fieldstr);
 	return mfid;
 }
@@ -99,7 +99,8 @@ output_query_results (MuMsgIter *iter, MuConfig *opts, GError **err)
 	case MU_CONFIG_FORMAT_LINKS:
 		return output_links (iter, opts->linksdir, opts->clearlinks, err);
 	case MU_CONFIG_FORMAT_PLAIN:
-		return output_plain (iter, opts->fields, opts->summary,
+		return output_plain (iter, opts->fields,
+				     opts->summary ? opts->summary_len : 0,
 				     opts->threads, !opts->nocolor,
 				     opts->include_unreadable, err);
 	case MU_CONFIG_FORMAT_XML:
@@ -159,7 +160,7 @@ exec_cmd (const char *path, const char *cmd, GError **err)
 	gboolean rv;
 
 	if (access (path, R_OK) != 0) {
-		g_set_error (err, 0, MU_ERROR_FILE_CANNOT_READ,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_FILE_CANNOT_READ,
 			     "cannot read %s: %s", path, strerror(errno));
 		return FALSE;
 	}
@@ -209,7 +210,7 @@ exec_cmd_on_query (MuQuery *xapian, const gchar *query, MuConfig *opts,
 	}
 
 	if (count == 0) {
-		g_set_error (err, 0, MU_ERROR_NO_MATCHES,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_NO_MATCHES,
 			     "no matches for search expression");
 		return FALSE;
 	}
@@ -231,20 +232,20 @@ format_params_valid (MuConfig *opts, GError **err)
 	case MU_CONFIG_FORMAT_XQUERY:
 		break;
 	default:
-		g_set_error (err, 0, MU_ERROR_IN_PARAMETERS,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_IN_PARAMETERS,
 			     "invalid output format %s",
 			     opts->formatstr ? opts->formatstr : "<none>");
 		return FALSE;
 	}
 
 	if (opts->format == MU_CONFIG_FORMAT_LINKS && !opts->linksdir) {
-		g_set_error (err, 0, MU_ERROR_IN_PARAMETERS,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_IN_PARAMETERS,
 			     "missing --linksdir argument");
 		return FALSE;
 	}
 
 	if (opts->linksdir && opts->format != MU_CONFIG_FORMAT_LINKS) {
-		g_set_error (err, 0, MU_ERROR_IN_PARAMETERS,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_IN_PARAMETERS,
 			     "--linksdir is only valid with --format=links");
 		return FALSE;
 	}
@@ -262,11 +263,12 @@ query_params_valid (MuConfig *opts, GError **err)
 	if (mu_util_check_dir (xpath, TRUE, FALSE))
 		return TRUE;
 
-	g_set_error (err, 0, MU_ERROR_FILE_CANNOT_READ,
+	g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_FILE_CANNOT_READ,
 		     "'%s' is not a readable Xapian directory", xpath);
 	return FALSE;
 }
 
+
 static gchar*
 resolve_bookmark (MuConfig *opts, GError **err)
 {
@@ -277,14 +279,14 @@ resolve_bookmark (MuConfig *opts, GError **err)
 	bmfile = mu_runtime_path (MU_RUNTIME_PATH_BOOKMARKS);
 	bm = mu_bookmarks_new (bmfile);
 	if (!bm) {
-		g_set_error (err, 0, MU_ERROR_FILE_CANNOT_OPEN,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_FILE_CANNOT_OPEN,
 			     "failed to open bookmarks file '%s'", bmfile);
 		return FALSE;
 	}
 
 	val = (gchar*)mu_bookmarks_lookup (bm, opts->bookmark);
 	if (!val)
-		g_set_error (err, 0, MU_ERROR_NO_MATCHES,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_NO_MATCHES,
 			     "bookmark '%s' not found", opts->bookmark);
 	else
 		val = g_strdup (val);
@@ -330,7 +332,7 @@ get_query (MuConfig *opts, GError **err)
 
 	/* params[0] is 'find', actual search params start with [1] */
 	if (!opts->bookmark && !opts->params[1]) {
-		g_set_error (err, 0, MU_ERROR_IN_PARAMETERS,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_IN_PARAMETERS,
 			     "error in parameters");
 		return NULL;
 	}
@@ -368,13 +370,13 @@ get_query_obj (MuStore *store, GError **err)
 		return NULL;
 
 	if (count == 0) {
-		g_set_error (err, 0, MU_ERROR_XAPIAN_IS_EMPTY,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_XAPIAN_IS_EMPTY,
 			     "the database is empty");
 		return NULL;
 	}
 
 	if (mu_store_needs_upgrade (store)) {
-		g_set_error (err, 0, MU_ERROR_XAPIAN_NOT_UP_TO_DATE,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_XAPIAN_NOT_UP_TO_DATE,
 			     "the database is not up-to-date");
 		return NULL;
 	}
@@ -468,13 +470,13 @@ output_links (MuMsgIter *iter, const char* linksdir, gboolean clearlinks,
 	}
 
 	if (errcount > 0) {
-		g_set_error (err, 0, MU_ERROR_FILE_CANNOT_LINK,
-			     "error linking %u message(s)", errcount);
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_FILE_CANNOT_LINK,
+			     "error linking %u message(s)", (unsigned)errcount);
 		return FALSE;
 	}
 
 	if (count == 0) {
-		g_set_error (err, 0, MU_ERROR_NO_MATCHES,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_NO_MATCHES,
 			     "no matches for search expression");
 		return FALSE;
 	}
@@ -566,14 +568,19 @@ display_field (MuMsg *msg, MuMsgFieldId mfid)
 
 
 static void
-print_summary (MuMsg *msg)
+print_summary (MuMsg *msg, int summary_len)
 {
+	const char* body;
 	char *summ;
 
-	const guint SUMMARY_LEN = 5; /* summary based on first 5
-				      * lines */
-	summ = mu_str_summarize (mu_msg_get_body_text(msg), SUMMARY_LEN);
-	g_print ("Summary: %s\n", summ ? summ : "<none>");
+	body = mu_msg_get_body_text(msg);
+
+	summ = body ? mu_str_summarize (body, (unsigned)summary_len) : NULL;
+
+	g_print ("Summary: ");
+	mu_util_fputs_encoded (summ ? summ : "<none>", stdout);
+	g_print ("\n");
+
 	g_free (summ);
 }
 
@@ -648,9 +655,8 @@ output_plain_fields (MuMsg *msg, const char *fields,
 }
 
 static gboolean
-output_plain (MuMsgIter *iter, const char *fields, gboolean summary,
-	      gboolean threads, gboolean color, gboolean include_unreadable,
-	      GError **err)
+output_plain (MuMsgIter *iter, const char *fields, int summary_len,
+	      gboolean threads, gboolean color, gboolean include_unreadable,  GError **err)
 {
 	MuMsgIter *myiter;
 	size_t count;
@@ -679,14 +685,14 @@ output_plain (MuMsgIter *iter, const char *fields, gboolean summary,
 
 		output_plain_fields (msg, fields, color, threads);
 
-		if (summary)
-			print_summary (msg);
+		if (summary_len > 0)
+			print_summary (msg, summary_len);
 
 		++count;
 	}
 
 	if (count == 0) {
-		g_set_error (err, 0, MU_ERROR_NO_MATCHES,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_NO_MATCHES,
 			     "no existing matches for search expression");
 		return FALSE;
 	}
@@ -746,7 +752,7 @@ output_sexp (MuMsgIter *iter, gboolean threads,
 	}
 
 	if (count == 0) {
-		g_set_error (err, 0, MU_ERROR_NO_MATCHES,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_NO_MATCHES,
 			     "no existing matches for search expression");
 		return FALSE;
 	}
@@ -765,7 +771,7 @@ output_xml_msg (MuMsg *msg)
 	print_attr_xml ("subject", mu_msg_get_subject (msg));
 	g_print ("\t\t<date>%u</date>\n",
 		 (unsigned)mu_msg_get_date (msg));
-	g_print ("\t\t<size>%u</size>\n", mu_msg_get_size (msg));
+	g_print ("\t\t<size>%u</size>\n", (unsigned)mu_msg_get_size (msg));
 	print_attr_xml ("msgid", mu_msg_get_msgid (msg));
 	print_attr_xml ("path", mu_msg_get_path (msg));
 	print_attr_xml ("maildir", mu_msg_get_maildir (msg));
@@ -803,7 +809,7 @@ output_xml (MuMsgIter *iter, gboolean include_unreadable, GError **err)
 	g_print ("</messages>\n");
 
 	if (count == 0) {
-		g_set_error (err, 0, MU_ERROR_NO_MATCHES,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_NO_MATCHES,
 			     "no existing matches for search expression");
 		return FALSE;
 	}
