@@ -130,7 +130,8 @@ mu_msg_part_get_text (MuMsgPart *self, gboolean *err)
 }
 
 
-
+/* note: this will return -1 in case of error or if the size is
+ * unknown */
 static ssize_t
 get_part_size (GMimePart *part)
 {
@@ -143,11 +144,11 @@ get_part_size (GMimePart *part)
 
 	stream = g_mime_data_wrapper_get_stream (wrapper);
 	if (!stream)
-		return -1;
+		return -1; /* no stream -> size is 0 */
+	else
+		return g_mime_stream_length (stream);
 
 	/* NOTE: it seems we shouldn't unref stream/wrapper */
-
-	return g_mime_stream_length (stream);
 }
 
 
@@ -337,7 +338,7 @@ write_part_to_fd (GMimePart *part, int fd, GError **err)
 
 	stream = g_mime_stream_fs_new (fd);
 	if (!GMIME_IS_STREAM(stream)) {
-		g_set_error (err, 0, MU_ERROR_GMIME,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_GMIME,
 			     "failed to create stream");
 		return FALSE;
 	}
@@ -345,7 +346,7 @@ write_part_to_fd (GMimePart *part, int fd, GError **err)
 
 	wrapper = g_mime_part_get_content_object (part);
 	if (!GMIME_IS_DATA_WRAPPER(wrapper)) {
-		g_set_error (err, 0, MU_ERROR_GMIME,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_GMIME,
 			     "failed to create wrapper");
 		g_object_unref (stream);
 		return FALSE;
@@ -353,10 +354,12 @@ write_part_to_fd (GMimePart *part, int fd, GError **err)
 	g_object_ref (part); /* FIXME: otherwise, the unrefs below
 			      * give errors...*/
 
-	rv = g_mime_data_wrapper_write_to_stream (wrapper, stream);
-	if (rv == -1)
-		g_set_error (err, 0, MU_ERROR_GMIME,
+	if (g_mime_data_wrapper_write_to_stream (wrapper, stream) == -1) {
+		rv = FALSE;
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_GMIME,
 			     "failed to write to stream");
+	} else
+		rv = TRUE;
 
 	g_object_unref (wrapper);
 	g_object_unref (stream);
@@ -373,13 +376,13 @@ write_object_to_fd (GMimeObject *obj, int fd, GError **err)
 	str = g_mime_object_to_string (obj);
 
 	if (!str) {
-		g_set_error (err, 0, MU_ERROR_GMIME,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_GMIME,
 			     "could not get string from object");
 		return FALSE;
 	}
 
 	if (write (fd, str, strlen(str)) == -1) {
-		g_set_error (err, 0, MU_ERROR_GMIME,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_GMIME,
 			     "failed to write object: %s",
 			     strerror(errno));
 		return FALSE;
@@ -405,7 +408,7 @@ save_mime_object (GMimeObject *obj, const char *fullpath,
 	/* ok, try to create the file */
 	fd = mu_util_create_writeable_fd (fullpath, 0600, overwrite);
 	if (fd == -1) {
-		g_set_error (err, 0, MU_ERROR_FILE,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_FILE,
 			     "could not open '%s' for writing: %s",
 			     fullpath, errno ? strerror(errno) : "error");
 		return FALSE;
@@ -417,7 +420,7 @@ save_mime_object (GMimeObject *obj, const char *fullpath,
 		rv = write_object_to_fd (obj, fd, err);
 
 	if (close (fd) != 0 && !err) { /* don't write on top of old err */
-		g_set_error (err, 0, MU_ERROR_FILE,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_FILE,
 			     "could not close '%s': %s",
 			     fullpath, errno ? strerror(errno) : "error");
 		return FALSE;
@@ -438,7 +441,7 @@ mu_msg_part_filepath (MuMsg *msg, const char* targetdir, guint partidx,
 		return NULL;
 
 	if (!(mobj = find_part (msg, partidx))) {
-		g_set_error (err, 0, MU_ERROR_GMIME, "cannot find part %u", partidx);
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_GMIME, "cannot find part %u", partidx);
 		return NULL;
 	}
 
@@ -455,7 +458,7 @@ mu_msg_part_filepath (MuMsg *msg, const char* targetdir, guint partidx,
 		fname  = get_filename_for_mime_message_part
 			(g_mime_message_part_get_message((GMimeMessagePart*)mobj));
 	else {
-		g_set_error (err, 0, MU_ERROR_GMIME, "part %u cannot be saved",
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_GMIME, "part %u cannot be saved",
 			     partidx);
 		return NULL;
 	}
@@ -521,7 +524,7 @@ mu_msg_part_save (MuMsg *msg, const char *fullpath, guint partidx,
 
 	part = find_part (msg, partidx);
 	if (!is_part_or_message_part (part)) {
-		g_set_error (err, 0, MU_ERROR_GMIME,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_GMIME,
 			     "unexpected type %s for part %u",
 			     G_OBJECT_TYPE_NAME((GObject*)part),
 			     partidx);
@@ -540,7 +543,7 @@ mu_msg_part_save_temp (MuMsg *msg, guint partidx, GError **err)
 
 	filepath = mu_msg_part_filepath_cache (msg, partidx);
 	if (!filepath) {
-		g_set_error (err, 0, MU_ERROR_FILE,
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_FILE,
 			     "Could not get temp filepath");
 		return NULL;
 	}
@@ -619,7 +622,7 @@ mu_msg_part_find_cid (MuMsg *msg, const char* sought_cid)
 
 	return msg_part_find_idx (msg->_file->_mime_msg,
 				  (MatchFunc)match_content_id,
-				  (gpointer)cid);
+				  (gpointer)(char*)cid);
 }
 
 struct _MatchData2 {
