@@ -1,6 +1,6 @@
 /* -*- mode: c; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 **
-** Copyright (C) 2008-2011 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2008-2012 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -93,7 +93,7 @@ mu_msg_new_from_file (const char *path, const char *mdir, GError **err)
 
 	if (G_UNLIKELY(!_gmime_initialized)) {
 		gmime_init ();
-		g_atexit (gmime_uninit);
+		atexit (gmime_uninit);
 	}
 
 	msgfile = mu_msg_file_new (path, mdir, err);
@@ -127,7 +127,7 @@ mu_msg_new_from_doc (XapianDocument *doc, GError **err)
 
 	if (G_UNLIKELY(!_gmime_initialized)) {
 		gmime_init ();
-		g_atexit (gmime_uninit);
+		atexit (gmime_uninit);
 	}
 
 	msgdoc = mu_msg_doc_new (doc, err);
@@ -564,7 +564,10 @@ fill_contact (MuMsgContact *self, InternetAddress *addr,
 	else
 		self->address  = NULL;
 
-	return TRUE;
+	/* note, the address could NULL e.g. when the recipient is something like
+	 * 'Undisclosed recipients'
+	 */
+	return self->address != NULL;
 }
 
 
@@ -572,11 +575,14 @@ static void
 address_list_foreach (InternetAddressList *addrlist, MuMsgContactType ctype,
 		      MuMsgContactForeachFunc func, gpointer user_data)
 {
-	int i;
+	int i, len;
 
-	for (i = 0; addrlist && i != internet_address_list_length(addrlist);
-	     ++i) {
+	if (!addrlist)
+		return;
 
+	len = internet_address_list_length(addrlist);
+
+	for (i = 0; i != len; ++i) {
 		MuMsgContact contact;
 		if (!fill_contact(&contact,
 				  internet_address_list_get_address (addrlist, i),
@@ -606,9 +612,9 @@ addresses_foreach (const char* addrs, MuMsgContactType ctype,
 }
 
 
-void
+static void
 msg_contact_foreach_file (MuMsg *msg, MuMsgContactForeachFunc func,
-			gpointer user_data)
+			  gpointer user_data)
 {
 	int i;
 	struct {
@@ -624,6 +630,10 @@ msg_contact_foreach_file (MuMsg *msg, MuMsgContactForeachFunc func,
 	addresses_foreach (g_mime_message_get_sender (msg->_file->_mime_msg),
 			   MU_MSG_CONTACT_TYPE_FROM, func, user_data);
 
+	/* reply_to */
+	addresses_foreach (g_mime_message_get_reply_to (msg->_file->_mime_msg),
+			   MU_MSG_CONTACT_TYPE_REPLY_TO, func, user_data);
+
 	/* get to, cc, bcc */
 	for (i = 0; i != G_N_ELEMENTS(ctypes); ++i) {
 		InternetAddressList *addrlist;
@@ -656,10 +666,10 @@ mu_msg_contact_foreach (MuMsg *msg, MuMsgContactForeachFunc func,
 	g_return_if_fail (msg);
 	g_return_if_fail (func);
 
-	if (msg->_doc)
-		msg_contact_foreach_doc (msg, func, user_data);
-	else if (msg->_file)
+	if (msg->_file)
 		msg_contact_foreach_file (msg, func, user_data);
+	else if (msg->_doc)
+		msg_contact_foreach_doc (msg, func, user_data);
 	else
 		g_return_if_reached ();
 }
@@ -736,31 +746,48 @@ mu_msg_is_readable (MuMsg *self)
  * that we got
  */
 char*
-get_target_mdir (MuMsg *msg, const char *maildir, GError **err)
+get_target_mdir (MuMsg *msg, const char *target_maildir, GError **err)
 {
 	char *rootmaildir, *rv;
+	const char *maildir;
+	gboolean not_top_level;
 
-	if (!mu_msg_get_maildir(msg)) {
-		g_set_error (err, 0, MU_ERROR_GMIME,
-			     "message misses maildir "
-			     "field, so cannot be moved");
+	/* maildir is the maildir stored in the message, e.g. '/foo' */
+	maildir = mu_msg_get_maildir(msg);
+	if (!maildir) {
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_GMIME,
+			     "message without maildir");
 		return NULL;
 	}
 
+	/* the 'rootmaildir' is the filesystem path from root to
+	 * maildir, ie.  /home/user/Maildir/foo */
 	rootmaildir = mu_maildir_get_maildir_from_path (mu_msg_get_path(msg));
 	if (!rootmaildir)
 		return NULL;
 
-	if (!g_str_has_suffix (rootmaildir, mu_msg_get_maildir(msg))) {
-		g_set_error (err, 0, MU_ERROR_FILE,
-			     "path is %s, but maildir is %s",
-			     mu_msg_get_path(msg), mu_msg_get_maildir(msg));
+	/* we do a sanity check: verify that that maildir is a suffix of
+	 * rootmaildir;*/
+	not_top_level = TRUE;
+	if (!g_str_has_suffix (rootmaildir, maildir) &&
+	    /* special case for the top-level '/' maildir, and
+	     * remember not_top_level */
+	    (not_top_level = (g_strcmp0 (maildir, "/") != 0))) {
+		g_set_error (err, MU_ERROR_DOMAIN, MU_ERROR_FILE,
+			     "path is '%s', but maildir is '%s' ('%s')",
+			     rootmaildir, mu_msg_get_maildir(msg),
+			     mu_msg_get_path (msg));
 		g_free (rootmaildir);
 		return NULL;
 	}
 
-	rootmaildir[strlen(rootmaildir) - strlen (mu_msg_get_maildir(msg))] = '\0';
-	rv = g_strconcat (rootmaildir, maildir, NULL);
+	/* if we're not at the top-level, remove the final '/' from
+	 * the rootmaildir */
+	if (not_top_level)
+		rootmaildir[strlen(rootmaildir) -
+			    strlen (mu_msg_get_maildir(msg))] = '\0';
+
+	rv = g_strconcat (rootmaildir, target_maildir, NULL);
 	g_free (rootmaildir);
 
 	return rv;
