@@ -137,6 +137,22 @@ mu_util_create_tmpdir (void)
 }
 
 
+GQuark
+mu_util_error_quark (void)
+{
+	static GQuark error_domain = 0;
+
+	if (G_UNLIKELY(error_domain == 0))
+		error_domain = g_quark_from_static_string
+			("mu-error-quark");
+
+	return error_domain;
+}
+
+
+
+
+
 const char*
 mu_util_cache_dir (void)
 {
@@ -150,33 +166,6 @@ mu_util_cache_dir (void)
 }
 
 
-gboolean
-mu_util_init_system (void)
-{
-	/* without setlocale, non-ascii cmdline params (like search
-	 * terms) won't work */
-	setlocale (LC_ALL, "");
-
-        /* on FreeBSD, it seems g_slice_new and friends lead to
-         * segfaults. Same for MacOS. We cannot easily debug what is
-         * going on there (no access to such a system), so all we can
-         * do is add a lame fallback -> we let g_slice_* use normal
-         * malloc
-         */
-#ifndef __linux__
-        if (!g_setenv ("G_SLICE", "always-malloc", TRUE)) {
-                g_critical ("cannot set G_SLICE");
-                return FALSE;
-        }
-        /* g_debug ("setting G_SLICE to always-malloc"); */
-#endif /*!__linux__*/
-
-	g_type_init ();
-
-	return TRUE;
-}
-
-
 gboolean
 mu_util_check_dir (const gchar* path, gboolean readable, gboolean writeable)
 {
@@ -205,39 +194,46 @@ mu_util_check_dir (const gchar* path, gboolean readable, gboolean writeable)
 gchar*
 mu_util_guess_maildir (void)
 {
-	const gchar *mdir1;
-	gchar *mdir2;
+        const gchar *mdir1, *home;
 
-	/* first, try MAILDIR */
-	mdir1 = g_getenv ("MAILDIR");
+        /* first, try MAILDIR */
+        mdir1 = g_getenv ("MAILDIR");
 
-	if (mdir1 && mu_util_check_dir (mdir1, TRUE, FALSE))
-		return g_strdup (mdir1);
+        if (mdir1 && mu_util_check_dir (mdir1, TRUE, FALSE))
+                return g_strdup (mdir1);
 
-	/* then, try ~/Maildir */
-	mdir2 = mu_util_dir_expand ("~/Maildir");
-	if (mu_util_check_dir (mdir2, TRUE, FALSE))
-		return mdir2;
+        /* then, try <home>/Maildir */
+        home = g_get_home_dir();
+        if (home) {
+                char *mdir2;
+                mdir2 = g_strdup_printf ("%s%cMaildir",
+                        home, G_DIR_SEPARATOR);
+                if (mu_util_check_dir (mdir2, TRUE, FALSE))
+                        return mdir2;
+                g_free (mdir2);
+        }
 
-	/* nope; nothing found */
-	return NULL;
+        /* nope; nothing found */
+        return NULL;
 }
 
 
 gchar*
 mu_util_guess_mu_homedir (void)
 {
-	const char* home;
+        const char* home;
 
-	/* g_get_home_dir use /etc/passwd, not $HOME; this is better,
-	 * as HOME may be wrong when using 'sudo' etc.*/
-	home = g_get_home_dir ();
+        /* g_get_home_dir use /etc/passwd, not $HOME; this is better,
+         * as HOME may be wrong when using 'sudo' etc.*/
+        home = g_get_home_dir ();
 
-	if (!home)
-		MU_WRITE_LOG ("failed to determine homedir");
+        if (!home) {
+                MU_WRITE_LOG ("failed to determine homedir");
+                return NULL;
+        }
 
-	return g_strdup_printf ("%s%c%s", home ? home : ".", G_DIR_SEPARATOR,
-				".mu");
+        return g_strdup_printf ("%s%c%s", home ? home : ".",
+				G_DIR_SEPARATOR, ".mu");
 }
 
 gboolean
@@ -327,12 +323,12 @@ mu_util_is_local_file (const char* path)
 
 
 gboolean
-mu_util_play (const char *path, gboolean allow_local, gboolean allow_remote)
+mu_util_play (const char *path, gboolean allow_local, gboolean allow_remote,
+	      GError **err)
 {
 	gboolean rv;
-	GError *err;
-	const gchar *prog;
-	char *cmdline, *escpath;
+	const gchar *argv[3];
+	const char *prog;
 
 	g_return_val_if_fail (path, FALSE);
 	g_return_val_if_fail (mu_util_is_local_file (path) || allow_remote,
@@ -349,19 +345,17 @@ mu_util_play (const char *path, gboolean allow_local, gboolean allow_remote)
 #endif /*!__APPLE__*/
 	}
 
-	escpath = g_strescape (path, NULL);
-	cmdline = g_strdup_printf ("%s \"%s\"", prog, escpath);
-	g_free (escpath);
+	argv[0] = prog;
+	argv[1] = path;
+	argv[2] = NULL;
 
 	err = NULL;
-	rv = g_spawn_command_line_async (cmdline, &err);
-	if (!rv) {
-		g_warning ("failed to spawn %s: %s",
-			   cmdline, err->message ? err->message : "error");
-		g_error_free (err);
-	}
-
-	g_free (cmdline);
+	rv = g_spawn_async (NULL,
+			    (gchar**)&argv,
+			    NULL,
+			    G_SPAWN_SEARCH_PATH,
+			    NULL, NULL, NULL,
+			    err);
 	return rv;
 }
 
@@ -419,14 +413,14 @@ mu_util_fputs_encoded (const char *str, FILE *stream)
 		GError *err;
 		unsigned bytes;
 		err = NULL;
-		conv = g_locale_from_utf8 (str, -1, &bytes, NULL, &err);
+		conv = g_locale_from_utf8 (str, -1, (gsize*)&bytes, NULL, &err);
 		if (!conv || err) {
 			/* conversion failed; this happens because is
 			 * some cases GMime may gives us non-UTF-8
 			 * string from e.g. wrongly encoded
 			 * message-subjects; if so, we escape the
 			 * string */
-			g_warning ("%s: fputs failed: %s",
+			g_warning ("%s: g_locale_from_utf8 failed: %s",
 				   __FUNCTION__,
 				   err ? err->message : "conversion failed");
 			g_clear_error (&err);
@@ -447,6 +441,27 @@ mu_util_fputs_encoded (const char *str, FILE *stream)
 
 
 
+void
+mu_util_g_set_error (GError **err, MuError errcode, const char *frm, ...)
+{
+	va_list ap;
+	char *msg;
+
+	/* don't bother with NULL errors, or errors already set */
+	if (!err || *err)
+		return;
+
+	msg = NULL;
+	va_start (ap, frm);
+	g_vasprintf (&msg, frm, ap);
+	va_end (ap);
+
+	g_set_error (err, MU_ERROR_DOMAIN, errcode, "%s", msg);
+
+	g_free (msg);
+}
+
+
 static gboolean
 print_args (FILE *stream, const char *frm, va_list args)
 {
