@@ -29,15 +29,6 @@
 
 G_BEGIN_DECLS
 
-/**
- * do system-specific initialization. should be called before anything
- * else. Initializes the locale and Gtype. Note: this function is
- * called by mu_runtime_init.
- *
- * @return TRUE if is succeeds, FALSE otherwise
- */
-gboolean mu_util_init_system (void);
-
 /**
  * get the expanded path; ie. perform shell expansion on the path. the
  * path does not have to exist
@@ -187,11 +178,25 @@ gboolean mu_util_printerr_encoded (const char *frm, ...) G_GNUC_PRINTF(1,2);
  * @param path full path of the file to open
  * @param allow_local allow local files (ie. with file:// prefix or fs paths)
  * @param allow_remote allow URIs (ie., http, mailto)
+ * @param err receives error information, if any
  *
  * @return TRUE if it succeeded, FALSE otherwise
  */
-gboolean mu_util_play (const char *path,
-		       gboolean allow_local, gboolean allow_remote);
+gboolean mu_util_play (const char *path, gboolean allow_local,
+		       gboolean allow_remote, GError **err);
+
+
+
+/**
+ * Get an error-query for mu, to be used in `g_set_error'. Recent
+ * version of Glib warn when using 0 for the error-domain in
+ * g_set_error.
+ *
+ *
+ * @return an error quark for mu
+ */
+GQuark mu_util_error_quark (void) G_GNUC_CONST;
+#define MU_ERROR_DOMAIN (mu_util_error_quark())
 
 
 /**
@@ -270,7 +275,6 @@ typedef gpointer XapianEnquire;
 	} while (0)
 
 
-
 /**
  *
  * don't repeat these catch blocks everywhere...
@@ -278,8 +282,9 @@ typedef gpointer XapianEnquire;
  */
 
 #define MU_STORE_CATCH_BLOCK_RETURN(GE,R)				\
-          catch (const MuStoreError& merr) {				\
-		g_set_error ((GE), 0, merr.mu_error(), "%s",		\
+        catch (const MuStoreError& merr) {				\
+		mu_util_g_set_error ((GE),					\
+			     merr.mu_error(), "%s",			\
 			     merr.what().c_str());			\
 		return (R);						\
 	  }								\
@@ -295,24 +300,27 @@ typedef gpointer XapianEnquire;
 
 #define MU_XAPIAN_CATCH_BLOCK_G_ERROR(GE,E)					\
 	  catch (const Xapian::DatabaseLockError &xerr) {			\
-		g_set_error ((GE),0,MU_ERROR_XAPIAN_CANNOT_GET_WRITELOCK,	\
+		mu_util_g_set_error ((GE),						\
+			     MU_ERROR_XAPIAN_CANNOT_GET_WRITELOCK,		\
 			     "%s: xapian error '%s'",				\
 			     __FUNCTION__, xerr.get_msg().c_str());		\
 	} catch (const Xapian::DatabaseCorruptError &xerr) {			\
-		g_set_error ((GE),0,MU_ERROR_XAPIAN_CORRUPTION,			\
+		mu_util_g_set_error ((GE),						\
+				MU_ERROR_XAPIAN_CORRUPTION,			\
 			     "%s: xapian error '%s'",				\
 			     __FUNCTION__, xerr.get_msg().c_str());		\
 	} catch (const Xapian::DatabaseError &xerr) {				\
-		  g_set_error ((GE),0,MU_ERROR_XAPIAN,				\
+		  mu_util_g_set_error ((GE),MU_ERROR_XAPIAN,				\
 			     "%s: xapian error '%s'",				\
 			     __FUNCTION__, xerr.get_msg().c_str());		\
 	} catch (const Xapian::Error &xerr) {					\
-		g_set_error ((GE),0,(E), "%s: xapian error '%s'",		\
+		mu_util_g_set_error ((GE),(E),					\
+			     "%s: xapian error '%s'",				\
 			     __FUNCTION__, xerr.get_msg().c_str());		\
         } catch (...) {								\
-		g_set_error ((GE),0,(MU_ERROR_INTERNAL),			\
+			mu_util_g_set_error ((GE),(MU_ERROR_INTERNAL),		\
 			     "%s: caught exception", __FUNCTION__);		\
-        }
+	 }
 
 
 #define MU_XAPIAN_CATCH_BLOCK_RETURN(R)					\
@@ -327,12 +335,14 @@ typedef gpointer XapianEnquire;
 
 #define MU_XAPIAN_CATCH_BLOCK_G_ERROR_RETURN(GE,E,R)			\
 	  catch (const Xapian::Error &xerr) {				\
-		g_set_error ((GE),0,(E),				\
+		mu_util_g_set_error ((GE),(E),				\
 			     "%s: xapian error '%s'",			\
 			   __FUNCTION__, xerr.get_msg().c_str());	\
 		return (R);						\
         } catch (...) {							\
-		g_set_error ((GE),0,(MU_ERROR_INTERNAL),		\
+		if ((GE)&&!(*(GE)))					\
+			mu_util_g_set_error ((GE),				\
+				     (MU_ERROR_INTERNAL),		\
 			     "%s: caught exception", __FUNCTION__);	\
 		return (R);						\
         }
@@ -428,6 +438,17 @@ enum _MuError {
 typedef enum _MuError MuError;
 
 
+/**
+ * set an error if it's not already set
+ *
+ * @param err errptr, or NULL
+ * @param errcode error code
+ * @param frm printf-style format, followed by paremeters
+ */
+void mu_util_g_set_error (GError **err, MuError errcode, const char *frm, ...)
+	G_GNUC_PRINTF(3,4);
+
+
 #define MU_COLOR_RED		"\x1b[31m"
 #define MU_COLOR_GREEN		"\x1b[32m"
 #define MU_COLOR_YELLOW		"\x1b[33m"
