@@ -103,7 +103,7 @@ run_and_count_matches (const char *xpath, const char *query)
 	if (g_test_verbose()) {
 		char *xs;
 		g_print ("\n==> query: %s\n", query);
-		xs = mu_query_preprocess (query);
+		xs = mu_query_preprocess (query, NULL);
 		g_print ("==> preproc: '%s'\n", xs);
 		g_free (xs);
 		xs = mu_query_as_string (mquery, query, NULL);
@@ -137,7 +137,6 @@ run_and_count_matches (const char *xpath, const char *query)
 	return count1;
 }
 
-
 typedef struct  {
 	const char *query;
 	size_t count; /* expected number of matches */
@@ -224,7 +223,6 @@ test_mu_query_03 (void)
 		g_assert_cmpuint (run_and_count_matches (xpath, queries[i].query),
 				  ==, queries[i].count);
 	g_free (xpath);
-
 }
 
 
@@ -235,10 +233,10 @@ test_mu_query_04 (void)
 	int i;
 
 	QResults queries[] = {
-		{ "frodo@example.com", 1}, /* does not match: see mu-find (1) */
+		{ "frodo@example.com", 1},
 		{ "f:frodo@example.com", 1},
 		{ "f:Frodo Baggins", 1},
-		{ "bilbo@anotherexample.com", 1}, /* same things */
+		{ "bilbo@anotherexample.com", 1},
 		{ "t:bilbo@anotherexample.com", 1},
 		{ "t:bilbo", 1},
 		{ "f:bilbo", 0},
@@ -257,10 +255,38 @@ test_mu_query_04 (void)
 		g_assert_cmpuint (run_and_count_matches (xpath, queries[i].query),
 				  ==, queries[i].count);
 	g_free (xpath);
-
 }
 
 
+static void
+test_mu_query_logic (void)
+{
+	gchar *xpath;
+	int i;
+
+	QResults queries[] = {
+		{ "subject:gcc" , 1},
+		{ "subject:lisp" , 1},
+		{ "subject:gcc OR subject:lisp" , 2},
+		{ "subject:gcc or subject:lisp" , 2},
+		{ "subject:gcc AND subject:lisp" , 0},
+
+		{ "subject:gcc OR (subject:scheme AND subject:elisp)" , 2},
+		{ "(subject:gcc OR subject:scheme) AND subject:elisp" , 1}
+	};
+
+	xpath = fill_database (MU_TESTMAILDIR);
+	g_assert (xpath != NULL);
+
+ 	for (i = 0; i != G_N_ELEMENTS(queries); ++i)
+		g_assert_cmpuint (run_and_count_matches (xpath, queries[i].query),
+				  ==, queries[i].count);
+	g_free (xpath);
+}
+
+
+
+
 static void
 test_mu_query_accented_chars_01 (void)
 {
@@ -489,7 +515,6 @@ test_mu_query_attach (void)
 
 	QResults queries[] = {
 		{ "j:sittingbull.jpg", 1},
-		{ "'file:sitting*'", 1},
 		{ "file:custer", 0},
 		{ "file:custer.jpg", 1}
 	};
@@ -563,6 +588,28 @@ test_mu_query_tags_02 (void)
 }
 
 
+static void
+test_mu_query_preprocess (void)
+{
+	unsigned u;
+	struct {
+		const gchar *expr, *expected;
+	} testcases [] = {
+		{ "hello", "hello" },
+		{ "/[Gmail].Sent Mail", "__gmail__sent mail" }
+		/* add more */
+	};
+
+
+ 	for (u = 0; u != G_N_ELEMENTS(testcases); ++u) {
+		gchar *prep;
+		prep = mu_query_preprocess (testcases[u].expr, NULL);
+		g_assert_cmpstr (prep, ==, testcases[u].expected);
+		g_free (prep);
+	}
+}
+
+
 
 
 int
@@ -572,10 +619,16 @@ main (int argc, char *argv[])
 
 	g_test_init (&argc, &argv, NULL);
 
+	g_test_add_func ("/mu-query/test-mu-query-preprocess",
+			 test_mu_query_preprocess);
+
 	g_test_add_func ("/mu-query/test-mu-query-01", test_mu_query_01);
 	g_test_add_func ("/mu-query/test-mu-query-02", test_mu_query_02);
 	g_test_add_func ("/mu-query/test-mu-query-03", test_mu_query_03);
 	g_test_add_func ("/mu-query/test-mu-query-04", test_mu_query_04);
+
+	g_test_add_func ("/mu-query/test-mu-query-logic", test_mu_query_logic);
+
 	g_test_add_func ("/mu-query/test-mu-query-accented-chars-1",
 			 test_mu_query_accented_chars_01);
 	g_test_add_func ("/mu-query/test-mu-query-accented-chars-2",
