@@ -102,7 +102,7 @@ test_mu_store_store_msg_and_count (void)
 
 	/* add one */
 	msg = mu_msg_new_from_file (
-		MU_TESTMAILDIR "cur/1283599333.1840_11.cthulhu!2,",
+		MU_TESTMAILDIR "/cur/1283599333.1840_11.cthulhu!2,",
 		NULL, NULL);
 	g_assert (msg);
 	g_assert_cmpuint (mu_store_add_msg (store, msg, NULL),
@@ -110,24 +110,24 @@ test_mu_store_store_msg_and_count (void)
 	g_assert_cmpuint (1,==,mu_store_count (store, NULL));
 	g_assert_cmpuint (TRUE,==,mu_store_contains_message
 			  (store,
-			   MU_TESTMAILDIR "cur/1283599333.1840_11.cthulhu!2,", NULL));
+			   MU_TESTMAILDIR "/cur/1283599333.1840_11.cthulhu!2,", NULL));
 	mu_msg_unref (msg);
 
 	/* add another one */
 	msg = mu_msg_new_from_file (MU_TESTMAILDIR2
-				    "bar/cur/mail3", NULL, NULL);
+				    "/bar/cur/mail3", NULL, NULL);
 	g_assert (msg);
 	g_assert_cmpuint (mu_store_add_msg (store, msg, NULL),
 			  !=, MU_STORE_INVALID_DOCID);
 	g_assert_cmpuint (2,==,mu_store_count (store, NULL));
 	g_assert_cmpuint (TRUE,==,
 			  mu_store_contains_message (store, MU_TESTMAILDIR2
-						     "bar/cur/mail3", NULL));
+						     "/bar/cur/mail3", NULL));
 	mu_msg_unref (msg);
 
 	/* try to add the first one again. count should be 2 still */
 	msg = mu_msg_new_from_file
-		(MU_TESTMAILDIR "cur/1283599333.1840_11.cthulhu!2,",
+		(MU_TESTMAILDIR "/cur/1283599333.1840_11.cthulhu!2,",
 		 NULL, NULL);
 	g_assert (msg);
 	g_assert_cmpuint (mu_store_add_msg (store, msg, NULL),
@@ -159,7 +159,7 @@ test_mu_store_store_msg_remove_and_count (void)
 	/* add one */
 	err = NULL;
 	msg = mu_msg_new_from_file (
-		MU_TESTMAILDIR "cur/1283599333.1840_11.cthulhu!2,",
+		MU_TESTMAILDIR "/cur/1283599333.1840_11.cthulhu!2,",
 		NULL, &err);
 	g_assert (msg);
 	g_assert_cmpuint (mu_store_add_msg (store, msg, NULL),
@@ -169,11 +169,11 @@ test_mu_store_store_msg_remove_and_count (void)
 
 	/* remove one */
 	mu_store_remove_path (store,
-			      MU_TESTMAILDIR "cur/1283599333.1840_11.cthulhu!2,");
+			      MU_TESTMAILDIR "/cur/1283599333.1840_11.cthulhu!2,");
 	g_assert_cmpuint (0,==,mu_store_count (store, NULL));
 	g_assert_cmpuint (FALSE,==,mu_store_contains_message
 			  (store,
-			   MU_TESTMAILDIR "cur/1283599333.1840_11.cthulhu!2,", NULL));
+			   MU_TESTMAILDIR "/cur/1283599333.1840_11.cthulhu!2,", NULL));
 	g_free (tmpdir);
 	mu_store_unref (store);
 }
