@@ -22,6 +22,10 @@
 #include <mu-str.h>
 #include <mu-date.h>
 
+#if HAVE_CONFIG_H
+#include <config.h>
+#endif /*HAVE_CONFIG_H*/
+
 /* 'private'/'protected' functions */
 static void mu_msg_header_view_class_init (MuMsgHeaderViewClass *klass);
 static void mu_msg_header_view_init       (MuMsgHeaderView *obj);
@@ -41,12 +45,21 @@ struct _MuMsgHeaderViewPrivate {
                                                 MU_TYPE_MSG_HEADER_VIEW, \
                                                 MuMsgHeaderViewPrivate))
 /* globals */
+#ifdef HAVE_GTK3
+static GtkBoxClass *parent_class = NULL;
+#else
 static GtkVBoxClass *parent_class = NULL;
+#endif /*!HAVE_GTK3*/
+
 
 /* uncomment the following if you have defined any signals */
 /* static guint signals[LAST_SIGNAL] = {0}; */
 
+#ifdef HAVE_GTK3
+G_DEFINE_TYPE (MuMsgHeaderView, mu_msg_header_view, GTK_TYPE_BOX);
+#else
 G_DEFINE_TYPE (MuMsgHeaderView, mu_msg_header_view, GTK_TYPE_VBOX);
+#endif /*!HAVE_GTK3*/
 
 
 static void
@@ -71,6 +84,12 @@ mu_msg_header_view_class_init (MuMsgHeaderViewClass *klass)
 static void
 mu_msg_header_view_init (MuMsgHeaderView *obj)
 {
+
+/* #ifdef HAVE_GTK3 */
+/* 	static GtkBoxClass *parent_class = NULL; */
+/* #endif /\*!HAVE_GTK3*\/ */
+
+
 	obj->_priv = MU_MSG_HEADER_VIEW_GET_PRIVATE(obj);
 	obj->_priv->_table = NULL;
 }
@@ -99,7 +118,7 @@ get_label (const gchar *txt, gboolean istitle)
 		markup = g_strdup_printf ("<b>%s</b>: ", txt);
 		gtk_label_set_markup (GTK_LABEL(label), markup);
 		gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_RIGHT);
-		g_free (markup);		
+		g_free (markup);
 	} else {
 		gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 		gtk_label_set_text (GTK_LABEL(label), txt ? txt : "");
@@ -121,7 +140,7 @@ add_row (GtkWidget *table, guint row, const char* fieldname, const char *value,
 	label = get_label (fieldname, TRUE);
 	al = gtk_alignment_new (0.0, 0.0, 0.0, 0.0);
 	gtk_container_add (GTK_CONTAINER (al), label);
-	
+
 	gtk_table_attach (
 		GTK_TABLE(table), al,
 		0, 1, row, row + 1, GTK_FILL, 0, 0, 0);
@@ -134,21 +153,21 @@ add_row (GtkWidget *table, guint row, const char* fieldname, const char *value,
 	gtk_table_attach (
 		GTK_TABLE(table), al, 1, 2, row, row + 1, GTK_FILL,
 		0, 0, 0);
-		
+
 	return TRUE;
 }
 
-	
+
 GtkWidget *
 get_table (MuMsg *msg)
 {
 	GtkWidget *table;
 	int row;
-	
+
 	row = 0;
 
 	table = gtk_table_new (5, 2, FALSE);
-	
+
 	if (add_row (table, row, "From", mu_msg_get_from (msg), TRUE))
 		++row;
 	if (add_row (table, row, "To", mu_msg_get_to (msg), FALSE))
@@ -170,7 +189,7 @@ void
 mu_msg_header_view_set_message (MuMsgHeaderView *self, MuMsg *msg)
 {
 	g_return_if_fail (MU_IS_MSG_HEADER_VIEW(self));
-	
+
 	if (self->_priv->_table) {
 		gtk_container_remove (GTK_CONTAINER(self), self->_priv->_table);
 		self->_priv->_table = NULL;
@@ -183,4 +202,3 @@ mu_msg_header_view_set_message (MuMsgHeaderView *self, MuMsg *msg)
 		gtk_widget_show_all (self->_priv->_table);
 	}
 }
-
